@@ -1,5 +1,5 @@
 """An easy-to-use ML framework."""
-__version__ = '0.5.1'
+__version__ = '0.6.2'
 
 import os
 import logging
@@ -15,6 +15,7 @@ CLASSICML_LOGGER.info('正在使用 {} 引擎'.format(os.environ['CLASSICML_ENGI
 from classicML.api import models
 from classicML.api import plots
 
+from classicML.api import BaseModel
 from classicML.api import AveragedOneDependentEstimator
 from classicML.api import AODE
 from classicML.api import BackPropagationNeuralNetwork
@@ -34,11 +35,13 @@ from classicML.api import SVC
 
 from classicML.backend import activations
 from classicML.backend import callbacks
+from classicML.backend import data
 from classicML.backend import initializers
 from classicML.backend import io
 from classicML.backend import kernels
 from classicML.backend import losses
 from classicML.backend import metrics
 from classicML.backend import optimizers
+from classicML.backend import tree
 
-from classicML import benchmarks
\ No newline at end of file
+from classicML import benchmarks
